Message class

Constructors

Message({String? id, Author? author, Map<String, dynamic>? status, String? channelMessageId, String? message, List? readBy, bool? forwarded, bool? isChild, dynamic parentId, bool? isDeleted, String? messageType, int? direction, String? recipient, String? channel, String? extension, DateTime? createdAt, String? interactionId, List<Attachment?> attachments = const [], DateTime? updatedAt, int? v, ExtraPayload? extraPayload, String? uniqueId, bool isDelivered = false})
Message.fromJson(Map<String, dynamic> json)
factory

Properties

attachments ↔ List<Attachment?>
getter/setter pair
author ↔ Author?
getter/setter pair
channel ↔ String?
getter/setter pair
channelMessageId ↔ String?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
direction ↔ int?
getter/setter pair
extension ↔ String?
getter/setter pair
extraPayload ↔ ExtraPayload?
getter/setter pair
forwarded ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
interactionId ↔ String?
getter/setter pair
isChild ↔ bool?
getter/setter pair
isDeleted ↔ bool?
getter/setter pair
isDelivered ↔ bool
getter/setter pair
message ↔ String?
getter/setter pair
messageType ↔ String?
getter/setter pair
parentId ↔ dynamic
getter/setter pair
readBy ↔ List?
getter/setter pair
recipient ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Map<String, dynamic>?
getter/setter pair
uniqueId ↔ String?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
v ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited