TokenData class

Constructors

TokenData({String? id, Campaign? campaign, String? socketToken, String? page, String? title, Branding? button, Branding? branding, Bot? bot, Body? body, bool? multipleInteractions, bool? showAgentNames, String? queue, List<String?>? welcomeButtons, String? website, bool? active, String? template, bool? socialMedia, List? socialChannels, String? chatBotHeader, String? chatBotHeaderDescription, String? chatBotName, String? fileStore, int? iat, int? exp})
TokenData.fromJson(Map<String, dynamic> json)
factory

Properties

active ↔ bool?
getter/setter pair
body ↔ Body?
getter/setter pair
bot ↔ Bot?
getter/setter pair
branding ↔ Branding?
getter/setter pair
button ↔ Branding?
getter/setter pair
campaign ↔ Campaign?
getter/setter pair
chatBotHeader ↔ String?
getter/setter pair
chatBotHeaderDescription ↔ String?
getter/setter pair
chatBotName ↔ String?
getter/setter pair
exp ↔ int?
getter/setter pair
fileStore ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iat ↔ int?
getter/setter pair
id ↔ String?
getter/setter pair
getter/setter pair
multipleInteractions ↔ bool?
getter/setter pair
page ↔ String?
getter/setter pair
queue ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAgentNames ↔ bool?
getter/setter pair
socialChannels ↔ List?
getter/setter pair
socialMedia ↔ bool?
getter/setter pair
socketToken ↔ String?
getter/setter pair
template ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
website ↔ String?
getter/setter pair
welcomeButtons ↔ List<String?>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited