ChatStyle class

Constructors

ChatStyle({dynamic bubbleStyle, Color appBarColor = Colors.black, Color appBarTextColor = Colors.white, bool appbarEnabled = true})

Properties

appBarColor ↔ Color
getter/setter pair
appbarEnabled ↔ bool
getter/setter pair
appBarTextColor ↔ Color
getter/setter pair
bubbleStyle ↔ BubbleStyle
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited