Config class

Constructors

Config({required String baseUrl, required String appId, History history = const History(show: false, view: HistoryView.inSingleView)})

Properties

appId → String
final
baseUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
history → History
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited