Created class

Constructors

Created({String? year, String? month, String? day, String? hour, String? minutes})
Created.fromJson(Map<String, dynamic> json)
factory

Properties

day ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ String?
getter/setter pair
minutes ↔ String?
getter/setter pair
month ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited