Email class

Constructors

Email({int? id, String? email, int? emailType, int? companyId, int? emailDefault, int? deleted, int? createdBy, int? updatedBy, DateTime? createdAt, DateTime? updatedAt})
Email.fromJson(Map<String, dynamic> json)
factory

Properties

companyId ↔ int?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
createdBy ↔ int?
getter/setter pair
deleted ↔ int?
getter/setter pair
email ↔ String?
getter/setter pair
emailDefault ↔ int?
getter/setter pair
emailType ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt ↔ DateTime?
getter/setter pair
updatedBy ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited