Interaction class

Constructors

Interaction({Caller caller = const Caller(), List<String> readBy = const [], bool status = false, String id = "", List<Participant> participants = const [], Agent agent = const Agent(), String channel = "", String extension = "", ExtraPayload extraPayload = const ExtraPayload(), DateTime? createdAt, DateTime? updatedAt, LastMessage? lastMessage, List emails = const [], int unread = 0, String interactionId = ""})
Interaction.fromJson(Map<String, dynamic> json)
factory

Properties

agent ↔ Agent
getter/setter pair
caller ↔ Caller
getter/setter pair
channel ↔ String
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
emails ↔ List
getter/setter pair
extension ↔ String
getter/setter pair
extraPayload ↔ ExtraPayload
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
interactionId ↔ String
getter/setter pair
lastMessage ↔ LastMessage?
getter/setter pair
participants ↔ List<Participant>
getter/setter pair
readBy ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ bool
getter/setter pair
unread ↔ int
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited