Participant class

Constructors

Participant({DateTime? joinDtTime, String? leaveDtTime, bool? isAdmin, bool? status, int? firstResponseTime, int? averageResponseTime, dynamic evaluatedBy, dynamic evaluatedFormId, dynamic evaluationStatus, dynamic location, String? id, String? name, String? role, dynamic customId})
Participant.fromJson(Map<String, dynamic> json)
factory

Properties

averageResponseTime ↔ int?
getter/setter pair
customId ↔ dynamic
getter/setter pair
evaluatedBy ↔ dynamic
getter/setter pair
evaluatedFormId ↔ dynamic
getter/setter pair
evaluationStatus ↔ dynamic
getter/setter pair
firstResponseTime ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
isAdmin ↔ bool?
getter/setter pair
joinDtTime ↔ DateTime?
getter/setter pair
leaveDtTime ↔ String?
getter/setter pair
location ↔ dynamic
getter/setter pair
name ↔ String?
getter/setter pair
role ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited