Queue class

Constructors

Queue({bool? inQueue, String? name, String? startDtTime, String? endDtTime, int? duration, int? ringTime})
Queue.fromJson(Map<String, dynamic> json)
factory

Properties

duration ↔ int?
getter/setter pair
endDtTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inQueue ↔ bool?
getter/setter pair
name ↔ String?
getter/setter pair
ringTime ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDtTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited