SocketService class

Constructors

SocketService()
factory

Properties

config ↔ Config
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
no setter
isInitialized → bool
no setter
reconnectionAttempts → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ Socket?
getter/setter pair
tokenData ↔ TokenData
getter/setter pair
user ↔ User
getter/setter pair

Methods

closeInteraction(String interactionId) → void
connect({required SocketData socketData, required TokenData tokenData, required User user, required Config config, required dynamic eventCallback(Map<String, dynamic>)}) → void
disconnect() → void
emmitEvent(String event, Map<String, dynamic> value) → void
getUrl(String? mediaId) → Future<String>
initializeSocketSession() → void
interactionFeedback(String interactionId, String? value, String? input, BuildContext context) → Future<void>
interactionMessage(String interactionId, int offset) → void
newInteraction(Message message, Map<String, dynamic>? customData) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInteraction() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited