SocketMediaWidget class

Inheritance

Constructors

SocketMediaWidget({Key? key, double? width, double? height, required Message message, required User user, required String messageId, required bool isDelivered, required bool isMe, required BubbleStyle style, required ChatStyle chatStyle, required String fileStore, required Config config, required dynamic downloadVideo({required dynamic stopLoading(), required String url})?, required dynamic downloadFile({required dynamic stopLoading(), required String url})?, required dynamic downloadAudio({required dynamic stopLoading(), required String url})?, required dynamic downloadImage({required dynamic stopLoading(), required String url})?})
const

Properties

chatStyle → ChatStyle
final
config → Config
final
downloadAudio → dynamic Function({required dynamic stopLoading(), required String url})?
final
downloadFile → dynamic Function({required dynamic stopLoading(), required String url})?
final
downloadImage → dynamic Function({required dynamic stopLoading(), required String url})?
final
downloadVideo → dynamic Function({required dynamic stopLoading(), required String url})?
final
fileStore → String
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isDelivered → bool
final
isMe → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → Message
final
messageId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → BubbleStyle
final
user → User
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SocketMediaWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited