Logs class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
criticalOnly()
→ void
-
Enable only critical logs (errors and warnings)
-
debug(dynamic value, {String tag = 'general'})
→ void
-
-
disableAll()
→ void
-
Disable all logs (use when issue is resolved)
-
enableAll()
→ void
-
Enable all logs (use for debugging production issues)
-
info(dynamic value, {String tag = 'general'})
→ void
-
-
logError(dynamic value, {String tag = 'general', dynamic error, StackTrace? stackTrace})
→ void
-
-
socketDebugMode()
→ void
-
Enable socket debugging specifically
-
warning(dynamic value, {String tag = 'general'})
→ void
-